@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## A real Try Catch Block Implementation Using Perl Filter - ~/lib/Nice/Try.pm
-## Version v0.2.0
+## Version v0.2.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/05/17
@@ -22,7 +22,7 @@ BEGIN
     use Filter::Util::Call;
     use Scalar::Util;
     use List::Util ();
-    our $VERSION = 'v0.2.0';
+    our $VERSION = 'v0.2.1';
     our $ERROR;
     our( $CATCH, $DIED, $EXCEPTION, $FINALLY, $HAS_CATCH, @RETVAL, $SENTINEL, $TRY, $WANTARRAY );
 }
@@ -897,7 +897,10 @@ if( CORE::defined( \$Nice::Try::WANTARRAY ) and
     {
         \$Nice::Try::BREAK = 'redo';
     }
-    CORE::return( \$Nice::Try::WANTARRAY ? \@Nice::Try::RETVAL : \$Nice::Try::RETVAL[0] );
+    else
+    {
+        CORE::return( \$Nice::Try::WANTARRAY ? \@Nice::Try::RETVAL : \$Nice::Try::RETVAL[0] );
+    }
 }
 elsif( scalar( \@Nice::Try::VOID ) )
 {
@@ -1288,7 +1291,7 @@ When run, this would produce, as one would expect:
 
 =head1 VERSION
 
-    v0.2.0
+    v0.2.1
 
 =head1 DESCRIPTION
 
@@ -1398,7 +1401,7 @@ Would produce:
         }
         catch( $oops )
         {
-            log->( "Error: $oops" );
+            $log->( "Error: $oops" );
             last;
         }
     }
@@ -1448,7 +1451,7 @@ For example L<TryCatch>
 
 =item 4 Others
 
-For example L<Syntax::Keyword::Try> and now perl with L<version 5.33 using experimental feature|https://perldoc.perl.org/blead/perlsyn#Try-Catch-Exception-Handling>.
+For example L<Syntax::Keyword::Try> and now perl with L<version 5.33.7 using experimental feature|https://perldoc.perl.org/blead/perlsyn#Try-Catch-Exception-Handling>.
 
 =back
 
